Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func PostTrim ¶
PostTrim checks to see if the string ends with the substring ".git", and if so, removes it.
func PreTrim ¶
PreTrim Checks to see if the first character is a path separator, and if so, removes it.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.